@@ -34,7 +34,9 @@ def Main():
         args.hailLog = os.path.abspath(args.hailLog)
 
     InitLogger(capLog=args.capLog)
-
+    Log(f'CAP Version: {Shared.runtime.capVersion}')
+    Log(f'CAP Log {Shared.runtime.capLog}')
+    
     CapMain(args)
 
 
